ROOT:=/home/home/in_ffsox
SRC:=$(ROOT)/src
DOC:=$(ROOT)/doc
TOOLS:=$(SRC)/../tools

include $(ROOT)/config.mk
vpath % $(SRC)

LIBA52:=1
LIBMAD:=1

ifeq (ffmpeg,$(BRANCH))
EDITION:=FFmpeg
FLAG:=__FFMPEG__
HOME:=http:\/\/ffmpeg.org\/
AUTOBUILD:=http:\/\/ffmpeg.zeranoe.com\/builds\/win32\/shared\/
else
$(error Unsupported prefix "$(BRANCH)".)
endif

CPPFLAGS+=-DUNICODE_INPUT_PLUGIN
CPPFLAGS+=-DFFSOX_VERSION=\"$(VERSION)\"
CPPFLAGS+=-D$(FLAG)
ifneq (,$(LIBA52))
CPPFLAGS+=-DCHOOSE_A52
endif
ifneq (,$(LIBMAD))
CPPFLAGS+=-DCHOOSE_MAD
endif

CFLAGS+=-Wall
#CFLAGS+=-Werror

CPPFLAGS+=-I.
CPPFLAGS+=-I$(WA_SDK)
CPPFLAGS+=-I$(TOOLS)/include
CPPFLAGS+=-I$(TOOLS)/$(PFX)/$(BRANCH)/include
CPPFLAGS+=-I$(TOOLS)/unpack/$(BRANCH)-export-snapshot
CPPFLAGS+=-I$(TOOLS)/$(PFX)/$(BRANCH)/build/$(BRANCH)-export-snapshot

LDFLAGS+=-L$(TOOLS)/lib

LDLIBS+=-lpb
LDLIBS+=-lwinmm
LDLIBS+=-lwsock32

MVCFLAGS+=-I$(WA_SDK)
MVCFLAGS+=-I$(WA_SDK)/Wasabi
MVCFLAGS+=-I$(MSSDK_HOME)/Include
MVCFLAGS+=-I$(MSVC_HOME)/VC/include

INCLS+=audio_out_internal.h
INCLS+=ffmpeg_stub.h
INCLS+=info.h
ifneq (,$(LIBA52))
INCLS+=liba52_stub.h
INCLS+=a52dec.h
endif
ifneq (,$(LIBMAD))
INCLS+=libmad_stub.h
endif
INCLS+=libsrc_stub.h
INCLS+=libsox_stub.h
INCLS+=madutil.h
INCLS+=plugin.h
INCLS+=names.h
INCLS+=strbuf.h
INCLS+=setdlgitemurl.h
INCLS+=setdlgitemurl_stub.h
INCLS+=vout.h
INCLS+=symbols/avcodec.h
INCLS+=symbols/avformat.h
INCLS+=symbols/avutil.h
ifneq (,$(LIBA52))
INCLS+=symbols/liba52.h
endif
ifneq (,$(LIBMAD))
INCLS+=symbols/libmad.h
endif
INCLS+=symbols/setdlgitemurl.h
INCLS+=symbols/sox.h
ifneq (,$(FFMPEG_SWSCALE))
INCLS+=symbols/swscale.h
endif
INCLS+=symbols/samplerate.h
INCLS+=resources.h

OBJS:=
OBJS+=libffsox.a(in_sox.o)
OBJS+=libffsox.a(in_ffsox.o)
OBJS+=libffsox.a(samplerate.o)
OBJS+=libffsox.a(sox.o)
OBJS+=libffsox.a(packet_queue.o)
ifneq (,$(EXPERIMENTAL))
OBJS+=libffsox.a(samplebuf_i16_p.o)
OBJS+=libffsox.a(samplebuf_i32_p.o)
OBJS+=libffsox.a(samplebuf_f32_p.o)
OBJS+=libffsox.a(samplebuf_f64_p.o)
OBJS+=libffsox.a(samplebuf_i16_i.o)
OBJS+=libffsox.a(samplebuf_i32_i.o)
OBJS+=libffsox.a(samplebuf_f32_i.o)
OBJS+=libffsox.a(samplebuf_f64_i.o)
endif
OBJS+=libffsox.a(samplebuf.o)
OBJS+=libffsox.a(strbuf.o)
OBJS+=libffsox.a(timer.o)
ifneq (,$(LIBA52))
OBJS+=libffsox.a(audio_out_raw32.o)
OBJS+=libffsox.a(double2s32.o)
OBJS+=libffsox.a(a52dec.o)
OBJS+=libffsox.a(liba52_adapter.o)
endif
ifneq (,$(LIBMAD))
OBJS+=libffsox.a(libmad_adapter.o)
OBJS+=libffsox.a(mad_sync.o)
endif
OBJS+=libffsox.a(prefs.o)
OBJS+=libffsox.a(about.o)
OBJS+=libffsox.a(ffmpeg_stub.o)
ifneq (,$(LIBA52))
OBJS+=libffsox.a(liba52_stub.o)
endif
ifneq (,$(LIBMAD))
OBJS+=libffsox.a(libmad_stub.o)
endif
OBJS+=libffsox.a(libsrc_stub.o)
OBJS+=libffsox.a(libsox_stub.o)
OBJS+=libffsox.a(setdlgitemurl_stub.o)
OBJS+=libffsox.a(screen.o)
OBJS+=libffsox.a(vout.o)

.PHONY:
all: in_ffsox/doc
all: in_ffsox/setdlgitemurl.dll
all: in_ffsox/libsox.dll
all: in_ffsox/libsamplerate-0.dll
ifeq (full,$(PFX))
all: in_ffsox/libmad.dll
all: in_ffsox/liba52.dll
endif
all: in_ffsox/avutil-52.dll
all: in_ffsox/avcodec-55.dll
all: in_ffsox/avformat-55.dll
ifneq (,$(FFMPEG_SWSCALE))
all: in_ffsox/swscale-2.dll
endif
all: in_ffsox.dll
in_ffsox.dll: main.o resources.o libffsox.a
	$(CC) -shared -mwindows $(LDFLAGS) $^ $(LDLIBS) -o $@
libffsox.a: $(OBJS)
main.o resources.o $(OBJS): $(INCLS)

in_ffsox/doc: FORCE
	mkdir -p $(@D)
	rm -rf $@
	cp -r $(DOC) $@
	cp $(ROOT)/COPYING $@
in_ffsox/%: $(TOOLS)/$(PFX)/$(BRANCH)/bin/%
	mkdir -p $(@D)
	cp $< $(@D)
in_ffsox/%: $(TOOLS)/bin/%
	mkdir -p $(@D)
	cp $< $(@D)
libffsox.a(samplebuf_%_i.o): samplebuf_i.c
	$(CC) -c -o samplebuf_$*_i.o -DINTERLEAVED -D$* $(CFLAGS) $(CPPFLAGS) $<
	ar rv libffsox.a samplebuf_$*_i.o
	rm -f samplebuf_$*_i.o
libffsox.a(samplebuf_%_p.o): samplebuf_p.c
	$(CC) -c -o samplebuf_$*_p.o -DPLANAR -D$* $(CFLAGS) $(CPPFLAGS) $<
	ar rv libffsox.a samplebuf_$*_p.o
	rm -f samplebuf_$*_p.o
libffsox.a(vout.o): $(SRC)/vout.cpp
	cl -nologo -c $(MVCFLAGS) $< -Fovout.o
	ar rv libffsox.a vout.o
	rm -f vout.o
resources.o: resources.rc resources.h
	windres $< $@
resources.rc: pp/resources.rc
	sed -e "s/\$$(V)/$(V)/g" -e "s/\$$(E)/$(EDITION)/g" -e "s/\$$(H)/$(HOME)/g" -e "s/\$$(A)/$(AUTOBUILD)/g" <$< >$@
resources.h: pp/resources.h
	cp $< $@

.PHONY: FORCE
FORCE:
