/*
 * video.c
 * Copyright (C) 2010 Peter Belkner <pbelkner@snafu.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "plugin.h"

//#define ORIGINAL

screen_t *screen_init(screen_t *s, In_Module *mod)
{
  s->mod=mod;
  s->vout=NULL;
  s->width=0;
  s->height=0;
  s->aspectratio=0.0;
  s->open=0;

  return s;
}

screen_t *screen_cleanup(screen_t *s)
{
#if ! defined (ORIGINAL)
  screen_reset(s);
#endif

  return s;
}

void screen_set(screen_t *s, int width, int height, double aspectratio)
{
  if (NULL==s->vout)
    s->vout=vout_get(s->mod->hMainWindow);

#if defined (ORIGINAL)
  vout_open(s->vout,width,height,aspectratio);
  vout_set_caption(s->vout,FFSOX);
#else // ! ORIGINAL
  if (!s->open) {
    vout_open(s->vout,width,height,aspectratio);
    vout_set_caption(s->vout,FFSOX);
  }
  else if (s->width!=width||s->height!=height||s->aspectratio!=aspectratio) {
    vout_close(s->vout);
    vout_open(s->vout,width,height,aspectratio);
    vout_set_caption(s->vout,FFSOX);
  }

  s->width=width;
  s->height=height;
  s->aspectratio=aspectratio;
  s->open=1;
#endif // ! ORIGINAL
}

void screen_reset(screen_t *s)
{
#if ! defined (ORIGINAL)
  if (s->open) {
    vout_close(s->vout);
    s->width=0;
    s->height=0;
    s->aspectratio=0.0;
    s->open=0;
  }
#endif // ! ORIGINAL
}

void screen_finish(screen_t *s)
{
#if defined (ORIGINAL)
  vout_close(s->vout);
#endif // ORIGINAL
}
